@@ -1,7 +1,8 @@
 # See https://demo.dataverse.org/dataverse/dataverse-client-r
 
 test_that("dataverse root", {
-  testthat::skip_if_offline("demo.dataverse.org")
+  # testthat::skip_if_offline("demo.dataverse.org")
+  testthat::skip_on_cran()
   expected_length_minimum <- 300 # 397 as of Feb 2020
 
   dv      <- get_dataverse(dataverse = ":root")
@@ -10,7 +11,8 @@ test_that("dataverse root", {
 })
 
 test_that("dataverse for 'dataverse-client-r'", {
-  testthat::skip_if_offline("demo.dataverse.org")
+  # testthat::skip_if_offline("demo.dataverse.org")
+  testthat::skip_on_cran()
   expected  <- structure(
     list(
       id = 1734004L,
@@ -21,6 +23,7 @@ test_that("dataverse for 'dataverse-client-r'", {
       publisher = "Demo Dataverse",
       publicationDate = "2020-12-29",
       storageIdentifier = "file://10.70122/FK2/HXJVJU",
+      metadataLanguage = "undefined",
       type = "dataset"
     ),
     class = "dataverse_dataset"
